@@ -28,6 +28,10 @@ from .._impl import (
     scout_chartdefinition_api_DefaultFill as DefaultFill,
     scout_chartdefinition_api_DisconnectedValueVisualization as DisconnectedValueVisualization,
     scout_chartdefinition_api_DisconnectedValueVisualizationVisitor as DisconnectedValueVisualizationVisitor,
+    scout_chartdefinition_api_EnumArrayCellConfig as EnumArrayCellConfig,
+    scout_chartdefinition_api_EnumArrayRawVisualisation as EnumArrayRawVisualisation,
+    scout_chartdefinition_api_EnumArrayVisualisation as EnumArrayVisualisation,
+    scout_chartdefinition_api_EnumArrayVisualisationVisitor as EnumArrayVisualisationVisitor,
     scout_chartdefinition_api_EnumCellConfig as EnumCellConfig,
     scout_chartdefinition_api_EnumGroupBySort as EnumGroupBySort,
     scout_chartdefinition_api_EnumGroupBySortCustom as EnumGroupBySortCustom,
@@ -57,6 +61,7 @@ from .._impl import (
     scout_chartdefinition_api_Geo3dOrientationPrincipalAxes as Geo3dOrientationPrincipalAxes,
     scout_chartdefinition_api_Geo3dOrientationVisitor as Geo3dOrientationVisitor,
     scout_chartdefinition_api_Geo3dPosition as Geo3dPosition,
+    scout_chartdefinition_api_Geo3dPositionEcef as Geo3dPositionEcef,
     scout_chartdefinition_api_Geo3dPositionVisitor as Geo3dPositionVisitor,
     scout_chartdefinition_api_Geo3dPositionWgs84 as Geo3dPositionWgs84,
     scout_chartdefinition_api_GeoAdditionalTileset as GeoAdditionalTileset,
@@ -98,6 +103,10 @@ from .._impl import (
     scout_chartdefinition_api_NeverConnectDisconnectedValues as NeverConnectDisconnectedValues,
     scout_chartdefinition_api_NumberFormat as NumberFormat,
     scout_chartdefinition_api_NumberFormatDisplayOption as NumberFormatDisplayOption,
+    scout_chartdefinition_api_NumericArrayCellConfig as NumericArrayCellConfig,
+    scout_chartdefinition_api_NumericArrayRawVisualisation as NumericArrayRawVisualisation,
+    scout_chartdefinition_api_NumericArrayVisualisation as NumericArrayVisualisation,
+    scout_chartdefinition_api_NumericArrayVisualisationVisitor as NumericArrayVisualisationVisitor,
     scout_chartdefinition_api_NumericBarGaugeVisualisation as NumericBarGaugeVisualisation,
     scout_chartdefinition_api_NumericBarVisualisationV2 as NumericBarVisualisationV2,
     scout_chartdefinition_api_NumericCellConfig as NumericCellConfig,
@@ -214,6 +223,10 @@ __all__ = [
     'DefaultFill',
     'DisconnectedValueVisualization',
     'DisconnectedValueVisualizationVisitor',
+    'EnumArrayCellConfig',
+    'EnumArrayRawVisualisation',
+    'EnumArrayVisualisation',
+    'EnumArrayVisualisationVisitor',
     'EnumCellConfig',
     'EnumGroupBySort',
     'EnumGroupBySortVisitor',
@@ -244,6 +257,7 @@ __all__ = [
     'Geo3dOrientationPrincipalAxes',
     'Geo3dPosition',
     'Geo3dPositionVisitor',
+    'Geo3dPositionEcef',
     'Geo3dPositionWgs84',
     'GeoAdditionalTileset',
     'GeoAdditionalVariable',
@@ -284,6 +298,10 @@ __all__ = [
     'NeverConnectDisconnectedValues',
     'NumberFormat',
     'NumberFormatDisplayOption',
+    'NumericArrayCellConfig',
+    'NumericArrayRawVisualisation',
+    'NumericArrayVisualisation',
+    'NumericArrayVisualisationVisitor',
     'NumericBarGaugeVisualisation',
     'NumericBarVisualisationV2',
     'NumericCellConfig',
