@@ -130,6 +130,7 @@ from .._impl import (
     scout_compute_api_EnumSeriesVisitor as EnumSeriesVisitor,
     scout_compute_api_EnumTimeRangeFilterSeries as EnumTimeRangeFilterSeries,
     scout_compute_api_EnumTimeShiftSeries as EnumTimeShiftSeries,
+    scout_compute_api_EnumToNumericSeries as EnumToNumericSeries,
     scout_compute_api_EnumUnionOperation as EnumUnionOperation,
     scout_compute_api_EnumUnionSeries as EnumUnionSeries,
     scout_compute_api_EqualityOperator as EqualityOperator,
@@ -508,6 +509,7 @@ __all__ = [
     'EnumSeriesEqualityRanges',
     'EnumTimeRangeFilterSeries',
     'EnumTimeShiftSeries',
+    'EnumToNumericSeries',
     'EnumUnionOperation',
     'EnumUnionSeries',
     'EqualityOperator',
