@@ -40,6 +40,7 @@ from .._impl import (
     scout_compute_resolved_api_EnumSeriesNodeVisitor as EnumSeriesNodeVisitor,
     scout_compute_resolved_api_EnumTimeRangeFilterSeriesNode as EnumTimeRangeFilterSeriesNode,
     scout_compute_resolved_api_EnumTimeShiftSeriesNode as EnumTimeShiftSeriesNode,
+    scout_compute_resolved_api_EnumToNumericSeriesNode as EnumToNumericSeriesNode,
     scout_compute_resolved_api_EnumUnionSeriesNode as EnumUnionSeriesNode,
     scout_compute_resolved_api_EventSearchNode as EventSearchNode,
     scout_compute_resolved_api_ExponentialCurve as ExponentialCurve,
@@ -205,6 +206,7 @@ __all__ = [
     'EnumSeriesNodeVisitor',
     'EnumTimeRangeFilterSeriesNode',
     'EnumTimeShiftSeriesNode',
+    'EnumToNumericSeriesNode',
     'EnumUnionSeriesNode',
     'EventSearchNode',
     'ExponentialCurve',
