@@ -1,6 +1,5 @@
 # coding=utf-8
 from .._impl import (
-    scout_savedviews_api_ArchiveSavedViewsRequest as ArchiveSavedViewsRequest,
     scout_savedviews_api_AssetSearchState as AssetSearchState,
     scout_savedviews_api_BatchGetSavedViewsResponse as BatchGetSavedViewsResponse,
     scout_savedviews_api_ChecklistSearchState as ChecklistSearchState,
@@ -14,6 +13,7 @@ from .._impl import (
     scout_savedviews_api_ResourceType as ResourceType,
     scout_savedviews_api_RunSearchState as RunSearchState,
     scout_savedviews_api_SavedView as SavedView,
+    scout_savedviews_api_SavedViewMetadata as SavedViewMetadata,
     scout_savedviews_api_SavedViewSortOptions as SavedViewSortOptions,
     scout_savedviews_api_SearchSavedViewsQuery as SearchSavedViewsQuery,
     scout_savedviews_api_SearchSavedViewsQueryList as SearchSavedViewsQueryList,
@@ -27,7 +27,6 @@ from .._impl import (
     scout_savedviews_api_SortKeyVisitor as SortKeyVisitor,
     scout_savedviews_api_TableState as TableState,
     scout_savedviews_api_TemplateSearchState as TemplateSearchState,
-    scout_savedviews_api_UnarchiveSavedViewsRequest as UnarchiveSavedViewsRequest,
     scout_savedviews_api_UpdateColor as UpdateColor,
     scout_savedviews_api_UpdateColorVisitor as UpdateColorVisitor,
     scout_savedviews_api_UpdateSavedViewRequest as UpdateSavedViewRequest,
@@ -38,7 +37,6 @@ from .._impl import (
 )
 
 __all__ = [
-    'ArchiveSavedViewsRequest',
     'AssetSearchState',
     'BatchGetSavedViewsResponse',
     'ChecklistSearchState',
@@ -52,6 +50,7 @@ __all__ = [
     'ResourceType',
     'RunSearchState',
     'SavedView',
+    'SavedViewMetadata',
     'SavedViewSortOptions',
     'SearchSavedViewsQuery',
     'SearchSavedViewsQueryVisitor',
@@ -65,7 +64,6 @@ __all__ = [
     'SortKeyVisitor',
     'TableState',
     'TemplateSearchState',
-    'UnarchiveSavedViewsRequest',
     'UpdateColor',
     'UpdateColorVisitor',
     'UpdateSavedViewRequest',
